use api::ApiArgs;
use clap::Parser;
#[cfg(feature = "client")]
use client::ClientCommand;

mod api;
mod certs;
#[cfg(feature = "client")]
mod client;

#[macro_export]
macro_rules! env_key {
    ( $var:expr ) => {
        concat!("SSH_CD_", $var)
    };
}

#[derive(Parser)]
enum Command {
    Server(ApiArgs),
    #[cfg(feature = "client")]
    Client(ClientCommand),
}

#[tokio::main(flavor = "current_thread")]
async fn main() -> anyhow::Result<()> {
    tracing_subscriber::fmt::init();

    match Command::parse() {
        Command::Server(args) => api::run(args).await?,
        #[cfg(feature = "client")]
        Command::Client(args) => client::run(args).await?,
    }
    Ok(())
}
